# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/chain_events.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import assets_pb2 as proto_dot_assets__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/chain_events.proto',
  package='vega',
  syntax='proto3',
  serialized_options=b'Z\037code.vegaprotocol.io/vega/proto',
  serialized_pb=b'\n\x18proto/chain_events.proto\x12\x04vega\x1a\x12proto/assets.proto\"K\n\x13\x42uiltinAssetDeposit\x12\x13\n\x0bvegaAssetID\x18\x01 \x01(\t\x12\x0f\n\x07partyID\x18\x02 \x01(\t\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x04\"N\n\x16\x42uiltinAssetWithdrawal\x12\x13\n\x0bvegaAssetID\x18\x01 \x01(\t\x12\x0f\n\x07partyID\x18\x02 \x01(\t\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x04\"\x81\x01\n\x11\x42uiltinAssetEvent\x12-\n\x07\x64\x65posit\x18\xe9\x07 \x01(\x0b\x32\x19.vega.BuiltinAssetDepositH\x00\x12\x33\n\nwithdrawal\x18\xea\x07 \x01(\x0b\x32\x1c.vega.BuiltinAssetWithdrawalH\x00\x42\x08\n\x06\x61\x63tion\"%\n\x0e\x45RC20AssetList\x12\x13\n\x0bvegaAssetID\x18\x01 \x01(\t\"\'\n\x10\x45RC20AssetDelist\x12\x13\n\x0bvegaAssetID\x18\x01 \x01(\t\"Y\n\x0c\x45RC20Deposit\x12\x13\n\x0bvegaAssetID\x18\x01 \x01(\t\x12\x1d\n\x15sourceEthereumAddress\x18\x02 \x01(\t\x12\x15\n\rtargetPartyID\x18\x03 \x01(\t\"t\n\x0f\x45RC20Withdrawal\x12\x13\n\x0bvegaAssetID\x18\x01 \x01(\t\x12\x15\n\rsourcePartyId\x18\x02 \x01(\t\x12\x1d\n\x15targetEthereumAddress\x18\x03 \x01(\t\x12\x16\n\x0ereferenceNonce\x18\x04 \x01(\t\"\xe6\x01\n\nERC20Event\x12\r\n\x05index\x18\x01 \x01(\x04\x12\r\n\x05\x62lock\x18\x02 \x01(\x04\x12*\n\tassetList\x18\xe9\x07 \x01(\x0b\x32\x14.vega.ERC20AssetListH\x00\x12.\n\x0b\x61ssetDelist\x18\xea\x07 \x01(\x0b\x32\x16.vega.ERC20AssetDelistH\x00\x12&\n\x07\x64\x65posit\x18\xeb\x07 \x01(\x0b\x32\x12.vega.ERC20DepositH\x00\x12,\n\nwithdrawal\x18\xec\x07 \x01(\x0b\x32\x15.vega.ERC20WithdrawalH\x00\x42\x08\n\x06\x61\x63tion\"R\n\nBTCDeposit\x12\x13\n\x0bvegaAssetID\x18\x01 \x01(\t\x12\x18\n\x10sourceBTCAddress\x18\x02 \x01(\t\x12\x15\n\rtargetPartyId\x18\x03 \x01(\t\"m\n\rBTCWithdrawal\x12\x13\n\x0bvegaAssetID\x18\x01 \x01(\t\x12\x15\n\rsourcePartyId\x18\x02 \x01(\t\x12\x18\n\x10targetBTCAddress\x18\x03 \x01(\t\x12\x16\n\x0ereferenceNonce\x18\x04 \x01(\t\"\x84\x01\n\x08\x42TCEvent\x12\r\n\x05index\x18\x01 \x01(\x04\x12\r\n\x05\x62lock\x18\x02 \x01(\x04\x12$\n\x07\x64\x65posit\x18\xe9\x07 \x01(\x0b\x32\x10.vega.BTCDepositH\x00\x12*\n\nwithdrawal\x18\xea\x07 \x01(\x0b\x32\x13.vega.BTCWithdrawalH\x00\x42\x08\n\x06\x61\x63tion\"\"\n\x0f\x45thereumAddress\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"!\n\x0e\x42itcoinAddress\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"|\n\nIdentifier\x12\x30\n\x0f\x65thereumAddress\x18\x01 \x01(\x0b\x32\x15.vega.EthereumAddressH\x00\x12.\n\x0e\x62itcoinAddress\x18\x02 \x01(\x0b\x32\x14.vega.BitcoinAddressH\x00\x42\x0c\n\nidentifier\",\n\x0c\x41\x64\x64Validator\x12\x1c\n\x02id\x18\x01 \x01(\x0b\x32\x10.vega.Identifier\"/\n\x0fRemoveValidator\x12\x1c\n\x02id\x18\x01 \x01(\x0b\x32\x10.vega.Identifier\"v\n\x0eValidatorEvent\x12\x10\n\x08sourceID\x18\x01 \x01(\t\x12\"\n\x03\x61\x64\x64\x18\xe9\x07 \x01(\x0b\x32\x12.vega.AddValidatorH\x00\x12$\n\x02rm\x18\xea\x07 \x01(\x0b\x32\x15.vega.RemoveValidatorH\x00\x42\x08\n\x06\x61\x63tion\"\xc0\x01\n\nChainEvent\x12\x0c\n\x04txID\x18\x01 \x01(\t\x12+\n\x07\x62uiltin\x18\xe9\x07 \x01(\x0b\x32\x17.vega.BuiltinAssetEventH\x00\x12\"\n\x05\x65rc20\x18\xea\x07 \x01(\x0b\x32\x10.vega.ERC20EventH\x00\x12\x1e\n\x03\x62tc\x18\xeb\x07 \x01(\x0b\x32\x0e.vega.BTCEventH\x00\x12*\n\tvalidator\x18\xec\x07 \x01(\x0b\x32\x14.vega.ValidatorEventH\x00\x42\x07\n\x05\x65ventB!Z\x1f\x63ode.vegaprotocol.io/vega/protob\x06proto3'
  ,
  dependencies=[proto_dot_assets__pb2.DESCRIPTOR,])




_BUILTINASSETDEPOSIT = _descriptor.Descriptor(
  name='BuiltinAssetDeposit',
  full_name='vega.BuiltinAssetDeposit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vegaAssetID', full_name='vega.BuiltinAssetDeposit.vegaAssetID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partyID', full_name='vega.BuiltinAssetDeposit.partyID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amount', full_name='vega.BuiltinAssetDeposit.amount', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54,
  serialized_end=129,
)


_BUILTINASSETWITHDRAWAL = _descriptor.Descriptor(
  name='BuiltinAssetWithdrawal',
  full_name='vega.BuiltinAssetWithdrawal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vegaAssetID', full_name='vega.BuiltinAssetWithdrawal.vegaAssetID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partyID', full_name='vega.BuiltinAssetWithdrawal.partyID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amount', full_name='vega.BuiltinAssetWithdrawal.amount', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=131,
  serialized_end=209,
)


_BUILTINASSETEVENT = _descriptor.Descriptor(
  name='BuiltinAssetEvent',
  full_name='vega.BuiltinAssetEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deposit', full_name='vega.BuiltinAssetEvent.deposit', index=0,
      number=1001, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='withdrawal', full_name='vega.BuiltinAssetEvent.withdrawal', index=1,
      number=1002, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='action', full_name='vega.BuiltinAssetEvent.action',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=212,
  serialized_end=341,
)


_ERC20ASSETLIST = _descriptor.Descriptor(
  name='ERC20AssetList',
  full_name='vega.ERC20AssetList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vegaAssetID', full_name='vega.ERC20AssetList.vegaAssetID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=343,
  serialized_end=380,
)


_ERC20ASSETDELIST = _descriptor.Descriptor(
  name='ERC20AssetDelist',
  full_name='vega.ERC20AssetDelist',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vegaAssetID', full_name='vega.ERC20AssetDelist.vegaAssetID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=382,
  serialized_end=421,
)


_ERC20DEPOSIT = _descriptor.Descriptor(
  name='ERC20Deposit',
  full_name='vega.ERC20Deposit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vegaAssetID', full_name='vega.ERC20Deposit.vegaAssetID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sourceEthereumAddress', full_name='vega.ERC20Deposit.sourceEthereumAddress', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='targetPartyID', full_name='vega.ERC20Deposit.targetPartyID', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=423,
  serialized_end=512,
)


_ERC20WITHDRAWAL = _descriptor.Descriptor(
  name='ERC20Withdrawal',
  full_name='vega.ERC20Withdrawal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vegaAssetID', full_name='vega.ERC20Withdrawal.vegaAssetID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sourcePartyId', full_name='vega.ERC20Withdrawal.sourcePartyId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='targetEthereumAddress', full_name='vega.ERC20Withdrawal.targetEthereumAddress', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='referenceNonce', full_name='vega.ERC20Withdrawal.referenceNonce', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=514,
  serialized_end=630,
)


_ERC20EVENT = _descriptor.Descriptor(
  name='ERC20Event',
  full_name='vega.ERC20Event',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='vega.ERC20Event.index', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block', full_name='vega.ERC20Event.block', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='assetList', full_name='vega.ERC20Event.assetList', index=2,
      number=1001, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='assetDelist', full_name='vega.ERC20Event.assetDelist', index=3,
      number=1002, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deposit', full_name='vega.ERC20Event.deposit', index=4,
      number=1003, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='withdrawal', full_name='vega.ERC20Event.withdrawal', index=5,
      number=1004, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='action', full_name='vega.ERC20Event.action',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=633,
  serialized_end=863,
)


_BTCDEPOSIT = _descriptor.Descriptor(
  name='BTCDeposit',
  full_name='vega.BTCDeposit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vegaAssetID', full_name='vega.BTCDeposit.vegaAssetID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sourceBTCAddress', full_name='vega.BTCDeposit.sourceBTCAddress', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='targetPartyId', full_name='vega.BTCDeposit.targetPartyId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=865,
  serialized_end=947,
)


_BTCWITHDRAWAL = _descriptor.Descriptor(
  name='BTCWithdrawal',
  full_name='vega.BTCWithdrawal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vegaAssetID', full_name='vega.BTCWithdrawal.vegaAssetID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sourcePartyId', full_name='vega.BTCWithdrawal.sourcePartyId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='targetBTCAddress', full_name='vega.BTCWithdrawal.targetBTCAddress', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='referenceNonce', full_name='vega.BTCWithdrawal.referenceNonce', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=949,
  serialized_end=1058,
)


_BTCEVENT = _descriptor.Descriptor(
  name='BTCEvent',
  full_name='vega.BTCEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='vega.BTCEvent.index', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block', full_name='vega.BTCEvent.block', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deposit', full_name='vega.BTCEvent.deposit', index=2,
      number=1001, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='withdrawal', full_name='vega.BTCEvent.withdrawal', index=3,
      number=1002, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='action', full_name='vega.BTCEvent.action',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1061,
  serialized_end=1193,
)


_ETHEREUMADDRESS = _descriptor.Descriptor(
  name='EthereumAddress',
  full_name='vega.EthereumAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='vega.EthereumAddress.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1195,
  serialized_end=1229,
)


_BITCOINADDRESS = _descriptor.Descriptor(
  name='BitcoinAddress',
  full_name='vega.BitcoinAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='vega.BitcoinAddress.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1231,
  serialized_end=1264,
)


_IDENTIFIER = _descriptor.Descriptor(
  name='Identifier',
  full_name='vega.Identifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ethereumAddress', full_name='vega.Identifier.ethereumAddress', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bitcoinAddress', full_name='vega.Identifier.bitcoinAddress', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='identifier', full_name='vega.Identifier.identifier',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1266,
  serialized_end=1390,
)


_ADDVALIDATOR = _descriptor.Descriptor(
  name='AddValidator',
  full_name='vega.AddValidator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='vega.AddValidator.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1392,
  serialized_end=1436,
)


_REMOVEVALIDATOR = _descriptor.Descriptor(
  name='RemoveValidator',
  full_name='vega.RemoveValidator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='vega.RemoveValidator.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1438,
  serialized_end=1485,
)


_VALIDATOREVENT = _descriptor.Descriptor(
  name='ValidatorEvent',
  full_name='vega.ValidatorEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sourceID', full_name='vega.ValidatorEvent.sourceID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='add', full_name='vega.ValidatorEvent.add', index=1,
      number=1001, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rm', full_name='vega.ValidatorEvent.rm', index=2,
      number=1002, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='action', full_name='vega.ValidatorEvent.action',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1487,
  serialized_end=1605,
)


_CHAINEVENT = _descriptor.Descriptor(
  name='ChainEvent',
  full_name='vega.ChainEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='txID', full_name='vega.ChainEvent.txID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='builtin', full_name='vega.ChainEvent.builtin', index=1,
      number=1001, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='erc20', full_name='vega.ChainEvent.erc20', index=2,
      number=1002, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='btc', full_name='vega.ChainEvent.btc', index=3,
      number=1003, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validator', full_name='vega.ChainEvent.validator', index=4,
      number=1004, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='event', full_name='vega.ChainEvent.event',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1608,
  serialized_end=1800,
)

_BUILTINASSETEVENT.fields_by_name['deposit'].message_type = _BUILTINASSETDEPOSIT
_BUILTINASSETEVENT.fields_by_name['withdrawal'].message_type = _BUILTINASSETWITHDRAWAL
_BUILTINASSETEVENT.oneofs_by_name['action'].fields.append(
  _BUILTINASSETEVENT.fields_by_name['deposit'])
_BUILTINASSETEVENT.fields_by_name['deposit'].containing_oneof = _BUILTINASSETEVENT.oneofs_by_name['action']
_BUILTINASSETEVENT.oneofs_by_name['action'].fields.append(
  _BUILTINASSETEVENT.fields_by_name['withdrawal'])
_BUILTINASSETEVENT.fields_by_name['withdrawal'].containing_oneof = _BUILTINASSETEVENT.oneofs_by_name['action']
_ERC20EVENT.fields_by_name['assetList'].message_type = _ERC20ASSETLIST
_ERC20EVENT.fields_by_name['assetDelist'].message_type = _ERC20ASSETDELIST
_ERC20EVENT.fields_by_name['deposit'].message_type = _ERC20DEPOSIT
_ERC20EVENT.fields_by_name['withdrawal'].message_type = _ERC20WITHDRAWAL
_ERC20EVENT.oneofs_by_name['action'].fields.append(
  _ERC20EVENT.fields_by_name['assetList'])
_ERC20EVENT.fields_by_name['assetList'].containing_oneof = _ERC20EVENT.oneofs_by_name['action']
_ERC20EVENT.oneofs_by_name['action'].fields.append(
  _ERC20EVENT.fields_by_name['assetDelist'])
_ERC20EVENT.fields_by_name['assetDelist'].containing_oneof = _ERC20EVENT.oneofs_by_name['action']
_ERC20EVENT.oneofs_by_name['action'].fields.append(
  _ERC20EVENT.fields_by_name['deposit'])
_ERC20EVENT.fields_by_name['deposit'].containing_oneof = _ERC20EVENT.oneofs_by_name['action']
_ERC20EVENT.oneofs_by_name['action'].fields.append(
  _ERC20EVENT.fields_by_name['withdrawal'])
_ERC20EVENT.fields_by_name['withdrawal'].containing_oneof = _ERC20EVENT.oneofs_by_name['action']
_BTCEVENT.fields_by_name['deposit'].message_type = _BTCDEPOSIT
_BTCEVENT.fields_by_name['withdrawal'].message_type = _BTCWITHDRAWAL
_BTCEVENT.oneofs_by_name['action'].fields.append(
  _BTCEVENT.fields_by_name['deposit'])
_BTCEVENT.fields_by_name['deposit'].containing_oneof = _BTCEVENT.oneofs_by_name['action']
_BTCEVENT.oneofs_by_name['action'].fields.append(
  _BTCEVENT.fields_by_name['withdrawal'])
_BTCEVENT.fields_by_name['withdrawal'].containing_oneof = _BTCEVENT.oneofs_by_name['action']
_IDENTIFIER.fields_by_name['ethereumAddress'].message_type = _ETHEREUMADDRESS
_IDENTIFIER.fields_by_name['bitcoinAddress'].message_type = _BITCOINADDRESS
_IDENTIFIER.oneofs_by_name['identifier'].fields.append(
  _IDENTIFIER.fields_by_name['ethereumAddress'])
_IDENTIFIER.fields_by_name['ethereumAddress'].containing_oneof = _IDENTIFIER.oneofs_by_name['identifier']
_IDENTIFIER.oneofs_by_name['identifier'].fields.append(
  _IDENTIFIER.fields_by_name['bitcoinAddress'])
_IDENTIFIER.fields_by_name['bitcoinAddress'].containing_oneof = _IDENTIFIER.oneofs_by_name['identifier']
_ADDVALIDATOR.fields_by_name['id'].message_type = _IDENTIFIER
_REMOVEVALIDATOR.fields_by_name['id'].message_type = _IDENTIFIER
_VALIDATOREVENT.fields_by_name['add'].message_type = _ADDVALIDATOR
_VALIDATOREVENT.fields_by_name['rm'].message_type = _REMOVEVALIDATOR
_VALIDATOREVENT.oneofs_by_name['action'].fields.append(
  _VALIDATOREVENT.fields_by_name['add'])
_VALIDATOREVENT.fields_by_name['add'].containing_oneof = _VALIDATOREVENT.oneofs_by_name['action']
_VALIDATOREVENT.oneofs_by_name['action'].fields.append(
  _VALIDATOREVENT.fields_by_name['rm'])
_VALIDATOREVENT.fields_by_name['rm'].containing_oneof = _VALIDATOREVENT.oneofs_by_name['action']
_CHAINEVENT.fields_by_name['builtin'].message_type = _BUILTINASSETEVENT
_CHAINEVENT.fields_by_name['erc20'].message_type = _ERC20EVENT
_CHAINEVENT.fields_by_name['btc'].message_type = _BTCEVENT
_CHAINEVENT.fields_by_name['validator'].message_type = _VALIDATOREVENT
_CHAINEVENT.oneofs_by_name['event'].fields.append(
  _CHAINEVENT.fields_by_name['builtin'])
_CHAINEVENT.fields_by_name['builtin'].containing_oneof = _CHAINEVENT.oneofs_by_name['event']
_CHAINEVENT.oneofs_by_name['event'].fields.append(
  _CHAINEVENT.fields_by_name['erc20'])
_CHAINEVENT.fields_by_name['erc20'].containing_oneof = _CHAINEVENT.oneofs_by_name['event']
_CHAINEVENT.oneofs_by_name['event'].fields.append(
  _CHAINEVENT.fields_by_name['btc'])
_CHAINEVENT.fields_by_name['btc'].containing_oneof = _CHAINEVENT.oneofs_by_name['event']
_CHAINEVENT.oneofs_by_name['event'].fields.append(
  _CHAINEVENT.fields_by_name['validator'])
_CHAINEVENT.fields_by_name['validator'].containing_oneof = _CHAINEVENT.oneofs_by_name['event']
DESCRIPTOR.message_types_by_name['BuiltinAssetDeposit'] = _BUILTINASSETDEPOSIT
DESCRIPTOR.message_types_by_name['BuiltinAssetWithdrawal'] = _BUILTINASSETWITHDRAWAL
DESCRIPTOR.message_types_by_name['BuiltinAssetEvent'] = _BUILTINASSETEVENT
DESCRIPTOR.message_types_by_name['ERC20AssetList'] = _ERC20ASSETLIST
DESCRIPTOR.message_types_by_name['ERC20AssetDelist'] = _ERC20ASSETDELIST
DESCRIPTOR.message_types_by_name['ERC20Deposit'] = _ERC20DEPOSIT
DESCRIPTOR.message_types_by_name['ERC20Withdrawal'] = _ERC20WITHDRAWAL
DESCRIPTOR.message_types_by_name['ERC20Event'] = _ERC20EVENT
DESCRIPTOR.message_types_by_name['BTCDeposit'] = _BTCDEPOSIT
DESCRIPTOR.message_types_by_name['BTCWithdrawal'] = _BTCWITHDRAWAL
DESCRIPTOR.message_types_by_name['BTCEvent'] = _BTCEVENT
DESCRIPTOR.message_types_by_name['EthereumAddress'] = _ETHEREUMADDRESS
DESCRIPTOR.message_types_by_name['BitcoinAddress'] = _BITCOINADDRESS
DESCRIPTOR.message_types_by_name['Identifier'] = _IDENTIFIER
DESCRIPTOR.message_types_by_name['AddValidator'] = _ADDVALIDATOR
DESCRIPTOR.message_types_by_name['RemoveValidator'] = _REMOVEVALIDATOR
DESCRIPTOR.message_types_by_name['ValidatorEvent'] = _VALIDATOREVENT
DESCRIPTOR.message_types_by_name['ChainEvent'] = _CHAINEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BuiltinAssetDeposit = _reflection.GeneratedProtocolMessageType('BuiltinAssetDeposit', (_message.Message,), {
  'DESCRIPTOR' : _BUILTINASSETDEPOSIT,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.BuiltinAssetDeposit)
  })
_sym_db.RegisterMessage(BuiltinAssetDeposit)

BuiltinAssetWithdrawal = _reflection.GeneratedProtocolMessageType('BuiltinAssetWithdrawal', (_message.Message,), {
  'DESCRIPTOR' : _BUILTINASSETWITHDRAWAL,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.BuiltinAssetWithdrawal)
  })
_sym_db.RegisterMessage(BuiltinAssetWithdrawal)

BuiltinAssetEvent = _reflection.GeneratedProtocolMessageType('BuiltinAssetEvent', (_message.Message,), {
  'DESCRIPTOR' : _BUILTINASSETEVENT,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.BuiltinAssetEvent)
  })
_sym_db.RegisterMessage(BuiltinAssetEvent)

ERC20AssetList = _reflection.GeneratedProtocolMessageType('ERC20AssetList', (_message.Message,), {
  'DESCRIPTOR' : _ERC20ASSETLIST,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.ERC20AssetList)
  })
_sym_db.RegisterMessage(ERC20AssetList)

ERC20AssetDelist = _reflection.GeneratedProtocolMessageType('ERC20AssetDelist', (_message.Message,), {
  'DESCRIPTOR' : _ERC20ASSETDELIST,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.ERC20AssetDelist)
  })
_sym_db.RegisterMessage(ERC20AssetDelist)

ERC20Deposit = _reflection.GeneratedProtocolMessageType('ERC20Deposit', (_message.Message,), {
  'DESCRIPTOR' : _ERC20DEPOSIT,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.ERC20Deposit)
  })
_sym_db.RegisterMessage(ERC20Deposit)

ERC20Withdrawal = _reflection.GeneratedProtocolMessageType('ERC20Withdrawal', (_message.Message,), {
  'DESCRIPTOR' : _ERC20WITHDRAWAL,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.ERC20Withdrawal)
  })
_sym_db.RegisterMessage(ERC20Withdrawal)

ERC20Event = _reflection.GeneratedProtocolMessageType('ERC20Event', (_message.Message,), {
  'DESCRIPTOR' : _ERC20EVENT,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.ERC20Event)
  })
_sym_db.RegisterMessage(ERC20Event)

BTCDeposit = _reflection.GeneratedProtocolMessageType('BTCDeposit', (_message.Message,), {
  'DESCRIPTOR' : _BTCDEPOSIT,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.BTCDeposit)
  })
_sym_db.RegisterMessage(BTCDeposit)

BTCWithdrawal = _reflection.GeneratedProtocolMessageType('BTCWithdrawal', (_message.Message,), {
  'DESCRIPTOR' : _BTCWITHDRAWAL,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.BTCWithdrawal)
  })
_sym_db.RegisterMessage(BTCWithdrawal)

BTCEvent = _reflection.GeneratedProtocolMessageType('BTCEvent', (_message.Message,), {
  'DESCRIPTOR' : _BTCEVENT,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.BTCEvent)
  })
_sym_db.RegisterMessage(BTCEvent)

EthereumAddress = _reflection.GeneratedProtocolMessageType('EthereumAddress', (_message.Message,), {
  'DESCRIPTOR' : _ETHEREUMADDRESS,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.EthereumAddress)
  })
_sym_db.RegisterMessage(EthereumAddress)

BitcoinAddress = _reflection.GeneratedProtocolMessageType('BitcoinAddress', (_message.Message,), {
  'DESCRIPTOR' : _BITCOINADDRESS,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.BitcoinAddress)
  })
_sym_db.RegisterMessage(BitcoinAddress)

Identifier = _reflection.GeneratedProtocolMessageType('Identifier', (_message.Message,), {
  'DESCRIPTOR' : _IDENTIFIER,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.Identifier)
  })
_sym_db.RegisterMessage(Identifier)

AddValidator = _reflection.GeneratedProtocolMessageType('AddValidator', (_message.Message,), {
  'DESCRIPTOR' : _ADDVALIDATOR,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.AddValidator)
  })
_sym_db.RegisterMessage(AddValidator)

RemoveValidator = _reflection.GeneratedProtocolMessageType('RemoveValidator', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEVALIDATOR,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.RemoveValidator)
  })
_sym_db.RegisterMessage(RemoveValidator)

ValidatorEvent = _reflection.GeneratedProtocolMessageType('ValidatorEvent', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATOREVENT,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.ValidatorEvent)
  })
_sym_db.RegisterMessage(ValidatorEvent)

ChainEvent = _reflection.GeneratedProtocolMessageType('ChainEvent', (_message.Message,), {
  'DESCRIPTOR' : _CHAINEVENT,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.ChainEvent)
  })
_sym_db.RegisterMessage(ChainEvent)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
